==> petitbasic-1.0b1.zip: src/org/logical_paradox/petitbasic/builtin/Tan.java <==
/*
 * $Id: Tan.java,v 1.1 2007/03/10 15:34:58 akabane Exp $
 * Copyright (c) 2006 LOGICAL-PARADOX.ORG
 */
package org.logical_paradox.petitbasic.builtin;

import org.logical_paradox.petitbasic.lex.Token;
import org.logical_paradox.petitbasic.operator.OperationUtils;
import org.logical_paradox.petitbasic.runtime.BasicCommandLine;
import org.logical_paradox.petitbasic.runtime.BasicRuntimeContext;
import org.logical_paradox.petitbasic.runtime.BasicRuntimeEnvironment;
import org.logical_paradox.petitbasic.runtime.ErrorCodeConstant;
import org.logical_paradox.petitbasic.runtime.Expression;
import org.logical_paradox.petitbasic.runtime.exception.BasicLanguageException;
import org.logical_paradox.petitbasic.runtime.mathpack.Real;

/**
 * TAN֐D
 * <br><pre>
 * @\F̐(TAN)vZD
 * ʁF֐<br>
 * FTAN(<>)
 * ᕶFA=TAN(90)
 * </pre>
 * @author satoshi akabane@logical-paradox.org
 * @version $Revision: 1.1 $
 */
public class Tan implements BuiltinCommand {
	/**
	 * R}hsD
	 * @param env ^C
	 * @param ctx ^CReLXg
	 * @param line BASICR}hs(runptr̗͂\̎̈ʒu|CgĂ)
	 * @return s(null: Ȃ)
	 * @throws BasicLanguageException BASICŃG[
	 */
	public Token execute(BasicRuntimeEnvironment env, BasicRuntimeContext ctx, BasicCommandLine line) throws BasicLanguageException {
		Expression expression = new Expression(env, ctx, line, true);
		Token token = expression.eval();
		if(expression.isTerminated() == false) {
			// ɑ(=ɑ)ꍇ̓G[Ƃ
			throw new BasicLanguageException(ErrorCodeConstant.SYNTAX_ERROR);
		}

		// ̌^ϊ
		Token value = OperationUtils.castValueType(token, Token.VTYPE_DBL, ctx);
		
		// ߎlvZ
		Real r = env.config.mathpack.fp_TAN(value.getRealValue());

		// vZʂ͏ɔ{x
		Token a = new Token(Token.TYPE_LITERAL);
		a.setRealValue(r);
		a.setValueType(Token.VTYPE_DBL);

		return a;
	}
}

==> petitbasic-1.0.2.zip: src/org/logical_paradox/petitbasic/builtin/Tan.java <==
/*
 * $Id: Tan.java,v 1.2 2008/11/12 18:01:05 akabane Exp $
 * Copyright (c) 2006 LOGICAL-PARADOX.ORG
 */
package org.logical_paradox.petitbasic.builtin;

import org.logical_paradox.petitbasic.lex.Token;
import org.logical_paradox.petitbasic.operator.OperationUtils;
import org.logical_paradox.petitbasic.runtime.BasicCommandLine;
import org.logical_paradox.petitbasic.runtime.BasicRuntimeContext;
import org.logical_paradox.petitbasic.runtime.BasicRuntimeEnvironment;
import org.logical_paradox.petitbasic.runtime.ErrorCodeConstant;
import org.logical_paradox.petitbasic.runtime.Expression;
import org.logical_paradox.petitbasic.runtime.exception.BasicLanguageException;
import org.logical_paradox.petitbasic.runtime.mathpack.Real;

/**
 * TAN֐D
 * <br><pre>
 * @\F̐(TAN)vZD
 * ʁF֐<br>
 * FTAN(<>)
 * ᕶFA=TAN(90)
 * </pre>
 * @author satoshi akabane@logical-paradox.org
 * @version $Revision: 1.2 $
 */
public class Tan implements BuiltinCommand {
	/**
	 * R}hsD
	 * @param env ^C
	 * @param ctx ^CReLXg
	 * @param line BASICR}hs(runptr̗͂\̎̈ʒu|CgĂ)
	 * @return s(null: Ȃ)
	 * @throws BasicLanguageException BASICŃG[
	 */
	public Token execute(BasicRuntimeEnvironment env, BasicRuntimeContext ctx, BasicCommandLine line) throws BasicLanguageException {
		Expression expression = new Expression(env, ctx, line, true);
		Token token = expression.eval();
		if(token == null || expression.isTerminated() == false) {
			// ɑ(=ɑ)ꍇ̓G[Ƃ
			throw new BasicLanguageException(ErrorCodeConstant.SYNTAX_ERROR);
		}

		// ̌^ϊ
		Token value = OperationUtils.castValueType(token, Token.VTYPE_DBL, ctx);
		
		// ߎlvZ
		Real r = env.config.mathpack.fp_TAN(value.getRealValue());

		// vZʂ͏ɔ{x
		Token a = new Token(Token.TYPE_LITERAL);
		a.setRealValue(r);
		a.setValueType(Token.VTYPE_DBL);

		return a;
	}
}
